"""
Environment variable key constants
"""

"""
The Azure Container App or Azure Kubernetes Service hostname.
"""
HOSTNAME = "HOSTNAME"

"""
The build version of the container. This is also used for the app version used
to validate the minimum version of the app required to use certain configuration entries.
"""
FOUNDATIONALLM_VERSION = "FOUNDATIONALLM_VERSION"



from enum import Enum

class ConfigurationTypes(str, Enum):
    """
    Enum for configuration types.
    """
    BASIC = "basic"
    API_ENDPOINT = "api-endpoint"
    APP_CONFIGURATION_KEY_VALUE = "appconfiguration-key-value"
    APP_CONFIGURATION_KEY_VAULT_REFERENCE = "appconfiguration-key-vault-reference"
